aboutsummaryrefslogtreecommitdiff
path: root/src/argaze/AreaOfInterest/AOI2DScene.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/argaze/AreaOfInterest/AOI2DScene.py')
-rw-r--r--src/argaze/AreaOfInterest/AOI2DScene.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/argaze/AreaOfInterest/AOI2DScene.py b/src/argaze/AreaOfInterest/AOI2DScene.py
index 4dc47f4..a726b23 100644
--- a/src/argaze/AreaOfInterest/AOI2DScene.py
+++ b/src/argaze/AreaOfInterest/AOI2DScene.py
@@ -26,9 +26,9 @@ AOI3DSceneType = TypeVar('AOI3DScene', bound="AOI3DScene")
class AOI2DScene(AOIFeatures.AOIScene):
"""Define AOI 2D scene."""
- def __init__(self, aois_2d: dict = None):
+ def __init__(self, aoi_2d: dict = None):
- super().__init__(2, aois_2d)
+ super().__init__(2, aoi_2d)
@classmethod
def from_svg(self, svg_filepath: str) -> AOI2DSceneType:
@@ -121,7 +121,7 @@ class AOI2DScene(AOIFeatures.AOIScene):
yield name, aoi, matching
def draw_raycast(self, image: numpy.array, pointer:tuple, exclude=[], base_color=(0, 0, 255), matching_color=(0, 255, 0)):
"""Draw AOIs with their matching status."""
for name, aoi, matching in self.raycast(pointer):
@@ -121,7 +121,7 @@ class AOI2DScene(AOIFeatures.AOIScene):
yield name, aoi, matching
def draw_raycast(self, image: numpy.array, pointer:tuple, exclude=[], base_color=(0, 0, 255), matching_color=(0, 255, 0)):
- """Draw AOIs with their matching status."""
+ """Draw AOI with their matching status."""
for name, aoi, matching in self.raycast(pointer):